import {Image, ScrollView, View, Text } from "@tarojs/components"
import Popup from "@/components/popup"
import LoadingCard from "@/components/loadingCard";
import Search from "@/components/search";
import InfiniteScroll from "@/components/infiniteScroll";
import Counter from "../counter";
import Big from 'big.js'
import classnames from "classnames";
import styles from "./index.module.scss"
import { memo, useCallback, useEffect, useMemo, useRef, useState } from "react";
import {GetColorList} from "@/api/materialColor"
import { useRouter } from "@tarojs/taro";
import UseLogin from "@/use/useLogin"
import { formatHashTag, formatMillionYuan } from "@/common/fotmat";
import { getFilterData } from "@/common/util";

type param = {
    show?: true|false,
    onClose?: () => void,
    title?: string,
    productId?: number
}
export default memo(({show = false, onClose, title = '', productId = 0}: param) => {
    const selectList = [
        {id: 0, step:1,  digits:0,  maxNum:100000,  defaultNum:1, title:'大货', unit:'件', eunit:'kg'},
        {id: 1, step:1,  digits:2,  maxNum:9.99, defaultNum:1, title:'剪板', unit:'米', eunit:'m'}, 
        {id: 2, step:1,  digits:2, minNum:10, maxNum:100000, defaultNum:10, title:'散剪', unit:'米', eunit:'kg'}, 
    ]
    const [selectIndex, setSelectIndex] = useState(0)
    const selectProduct = (index:number) => {
        setSelectIndex(index)
    }
   
    //获取面料颜色列表
    const {fetchData:colorFetchData} = GetColorList()
    const [list, setList] = useState<any[]>([])
    const [loading, setLoading] = useState(false)
    const condition = useRef({physical_warehouse:1, sale_mode:selectIndex, product_id:0, code_or_name:null})
    const getColorList = async () => {
        setLoading(() => true)
        console.log('数据:::',getFilterData(condition.current))
        let {data} = await colorFetchData(getFilterData(condition.current))
        setList([...data.list])
        setLoading(() => false)
    }
    const [showPopup, setShowPopup] = useState(false)
    //显示获取
    useEffect(() => {
        if(show) {
            condition.current.product_id = productId
            getColorList()
        }
        setShowPopup(show)
    }, [show])

    //卸载清空
    useEffect(() => {
        return () => {
            setList([])
        }
    }, [])

    //popup关闭
    const closePopup = () => {
        onClose?.()
        setShowPopup(false)
    }

    //计算总数量和总米/件数
    const [selectCount, setSelectCount] = useState({
        sumCount: 0,
        kindCount: 0
    })
    useEffect(() => {
        let sumCount = 0, kindCount = 0
        list.map(item => {
            if(item.count > 0) {
                sumCount = Big(sumCount).add(item.count).toNumber()
                kindCount ++
            }
        })
        setSelectCount({sumCount, kindCount})
    }, [list])

    //计数组件
    const getInputValue = (num, item) => {
       item.count = parseFloat(num)
       if(num == 0) item.show = false
       setList([...list])
       console.log(num)
    }
    const onAdd = (item) => {
        item.show = true
        item.count = selectList[selectIndex].defaultNum
        console.log('aa:::',item.count)
        setList((list) => [...list])
    }

    //搜索显示与隐藏
    const [searchShow, setSearchShow] = useState(false)
    const changeSearchShow = () => {
        setSearchShow(true)
    }

    //添加购物车
    const {getSelfUserInfo} = UseLogin()
    const addShopCart =  () => {
        getSelfUserInfo()
    }

    //显示金额
    const priceFormat = useCallback((item) => {
        let price = 0
        if(selectIndex == 0) {
            price = formatMillionYuan(item.bulk_price, 100).num
        } else if(selectIndex == 1) {
            price = formatMillionYuan(item.length_cut_price, 100).num
        } else {
            price = formatMillionYuan(item.weight_cut_price, 100).num
        }
        return <View className={styles.priceText}><Text>¥</Text>{Number(price) }<Text>{' /' + selectList[selectIndex].eunit}</Text></View> 
    }, [list, selectIndex])

    //重置数据
    useEffect(() => {
        const newList = list.map(item => {
            item.count = 0
            item.show = false
            return item
        })
        setList([...newList])
    }, [selectIndex])

    //筛选数据
    const searchInput = (e) => {
        condition.current.code_or_name = e
        getColorList()
    }

    return (
        <View className={styles.shop_cart_main}>
            
            <Popup showTitle={false} show={showPopup} onClose={() => closePopup()}>
                <View className={styles.popup_con}>
                    <View className={styles.header}>{title}</View>
                    <View className={styles.search}>
                        <View className={styles.search_title}>下单类型:</View>
                        <View className={styles.search_list}>
                            {selectList.map((item, index) => {
                                return <View key={index} onClick={() => selectProduct(index)} className={classnames(styles.search_item, (selectIndex==index)&&styles.search_item_select)}>{item.title}</View>
                            })}
                        </View>
                    </View>
                    {searchShow&&<View className={styles.colorFind}>
                        <View className={styles.search}>
                            <Search placeIcon="out" changeOnSearch={(e) => searchInput(e)} debounceTime={400}/>
                        </View>
                        <View className={styles.text} onClick={() => setSearchShow(false)}>取消</View>
                    </View>}
                    <View className={styles.colorNum}>
                        <View className={styles.title}>颜色分类 (13) {list.length}</View>
                        {!searchShow&&<View className={classnames('iconfont icon-sousuo', styles.miconfont)} onClick={() => changeSearchShow()}></View>}
                    </View>
                    
                    <View className={styles.product_color_con}>
                        {list.length > 0&&<InfiniteScroll moreStatus={false}>
                            <View className={styles.color_con}>
                                {list.map(item => {
                                    return <View className={styles.item}>
                                        <View className={styles.item_color}>
                                            <Image src={item.texture_url}/>
                                        </View>
                                        <View className={styles.item_con}>
                                            <View className={styles.title}>{formatHashTag(item.code, item.name)}</View>
                                            <View className={styles.num}>{priceFormat(item)}</View>
                                        </View>
                                        <View className={styles.btn_con}>
                                            {!item.show&&<View className={styles.btn} onClick={() => onAdd(item)}>添加</View>
                                            ||<View className={styles.btn_count}>
                                                <Counter
                                                    onBlue={(e) => getInputValue(e, item)} 
                                                    defaultNum={item.count}   
                                                    step={selectList[selectIndex].step} 
                                                    digits={selectList[selectIndex].digits}
                                                    onClickBtn={(e) => getInputValue(e, item)}
                                                    unit={selectList[selectIndex].unit}
                                                    minNum={selectList[selectIndex].minNum}
                                                    maxNum={selectList[selectIndex].maxNum}
                                                />
                                            </View>}
                                        </View>
                                    </View>
                                })}
                            </View>
                        </InfiniteScroll>||
                        <View className={styles.noData}>暂无此商品</View>}
                    </View>
                    <View className={styles.buy_btn}>
                        <View className={styles.buy_btn_con}>
                            <View className={styles.count}>当前已选{selectCount.kindCount}种，共{selectCount.sumCount}{selectList[selectIndex].unit}</View>
                            <View className={classnames(styles.add_cart, selectCount.kindCount&&styles.select_add_cart)} onClick={() => addShopCart()}>加入购物车</View>
                        </View>
                    </View>
                </View>
                <View className="common_safe_area_y"></View>
            </Popup>
        </View>
    )
})